@@ -2,5 +2,6 @@ from .batch_update_body import BatchUpdateBody, WriteControl  # isort:skip
 from .delete_content_range_request import DeleteContentRange
 from .insert_inline_image_request import InsertInlineImage
 from .insert_table_request import InsertTable
-from .replace_all_text_request import ReplaceAllText
+from .models import *
+from .replace_all_text_request import ReplaceAllText, SubstringMatchCriteria
 from .update_table_cell_style_request import UpdateTableCellStyle
